#
# Makefile Template for Tessy
# Compiler   : IAR iccavr
# Environment: IAR C-SPY
#

# Defines to be generated by Tessy:
#
# TESSY_SYS          :=
# MODULE_PATH        :=
# TESTOBJECT         :=
# USER_LINK_OPTIONS  :=
# COMPILER_INSTALL_PATH :=
# TARGET_INSTALL_PATH   :=

#####################################################################
#BEGIN_DEFINES
#####################################################################


TESSY_SYS_DOS		:=	$(shell cygpath -w $(TESSY_SYS))
MODULE_PATH_DOS	:=	$(shell cygpath -w $(MODULE_PATH))
IAR_HOME				:= $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
CSPY_HOME			:= $(shell ts_pathname -s '$(TARGET_INSTALL_PATH)')

all	 : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.d90

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE		:=	$(TESSY_SYS)/make/master_cspy_gnu_i386.mk
S_COMM_MAKE		:=	$(TESSY_SYS)/src/comm/comm_cspy_iar_avr.mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
S_COMP_OPTIONS := -ms --cpu=$(CPU) -e -z2 --debug --no_cse --no_inline --no_code_motion --no_cross_call --no_clustering --no_tbaa \
                  -D TESSY -D TS_SLAVE -D TS_CSPY -D TS_HAVE_FLOAT32
S_LINK_OPTIONS	:= -rt -I$(IAR_HOME)\lib\clib\ -f $(LINKER_CMD) $(RTL)
S_INCLUDES		:= -I $(IAR_HOME)\inc\ -I $(IAR_HOME)\inc\clib\ -I $(TESSY_SYS_DOS)\include\tessy\comm\ -I $(MODULE_PATH_DOS)\

S_CC				:=	$(IAR_HOME)\bin\iccavr
S_LINK			:=	$(IAR_HOME)\bin\xlink
S_OBJECTS  		:= $(MODULE_PATH_DOS)\tslows_cspy.r90 \
             		$(MODULE_PATH_DOS)\tstcomm.r90 \
             		$(MODULE_PATH_DOS)\tscoml.r90
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.r90
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.r90

#####################################################################
#END_DEFINES
#####################################################################

# Targets to be defined by Tessy
#
# for each source
#
# S_SRC_OBJECTS      := $(MODULE_PATH)/ts_src01.o ... ts_srcnn.o
# USER_COMP_OPTIONS* :=
# S_C1_OBJECTS       := $(MODULE_PATH)/ts_c1c01.o ... ts_c1cnn.o
#
# $(MODULE_PATH)/ts_src*.o : $(MODULE_PATH)/ts_src*.c
#     $(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $(USER_COMP_OPTIONS*) $<
#
# $(MODULE_PATH)/ts_c1c*.o : $(MODULE_PATH)/ts_c1c*.c
#     $(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $(USER_COMP_OPTIONS*) $<
#		@echo $@ >> $(MODULE_PATH_DOS)\ts_c1o

#####################################################################
#BEGIN_TARGETS
#####################################################################


# Don't show action lines
# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.r90 : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.d90 : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.r90 \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_C1_OBJECTS) \
															$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.r90 $(S_STUB_OBJECT) $(S_UC_OBJECT) $(S_SRC_OBJECTS) $(S_C1_OBJECTS) $(USER_LINK_OPTIONS) $(S_OBJECTS) -o "$@" $(S_LINK_OPTIONS)
	@-rm "$(MODULE_PATH)"/*.r90


#####################################################################
#END_TARGETS
#####################################################################












